@@ -152,6 +152,14 @@ class TestProblem(unittest.TestCase):
             assert goal_literal.get_polarity() is True
             assert str(goal_literal.get_atom()) in expected_goal_condition
 
+    def test_numeric_goal_condition(self):
+        domain_path = DATA_DIR / 'refuel' / 'domain.pddl'
+        problem_path = DATA_DIR / 'refuel' / 'test_problem.pddl'
+        domain = Domain(domain_path)
+        problem = Problem(domain, problem_path)
+        actual_numeric_goal_condition = problem.get_numeric_goal_condition()
+        pass
+
     def test_str_repr_hash(self):
         domain_path = DATA_DIR / 'blocks_4' / 'domain.pddl'
         problem_path = DATA_DIR / 'blocks_4' / 'test_problem.pddl'
@@ -537,6 +545,43 @@ class TestSearchAlgorithms(unittest.TestCase):
         assert heuristic.compute_value(initial_state, False) == 4.0
         assert len(heuristic.get_preferred_actions()) == 2
 
+    def test_iw(self):
+        domain_path = DATA_DIR / 'blocks_4' / 'domain.pddl'
+        problem_path = DATA_DIR / 'blocks_4' / 'test_problem.pddl'
+        domain = Domain(domain_path)
+        problem = Problem(domain, problem_path)
+        initial_state = problem.get_initial_state()
+        result = iw(problem, initial_state, 1)
+        assert result.status == "failed"
+        assert result.solution is None
+        assert result.solution_cost is None
+        assert result.goal_state is None
+
+    def test_iw_events(self):
+        domain_path = DATA_DIR / 'childsnack' / 'domain.pddl'
+        problem_path = DATA_DIR / 'childsnack' / 'test_problem.pddl'
+        domain = Domain(domain_path)
+        problem = Problem(domain, problem_path)
+        initial_state = problem.get_initial_state()
+        expanded_states = []
+        expanded_goal_states = []
+        generated_states = []
+        generated_new_states = []
+        pruned_states = []
+        _ = iw(problem,
+               initial_state,
+               1,
+               on_expand_state=lambda state: expanded_states.append(state),
+               on_expand_goal_state=lambda state: expanded_goal_states.append(state),
+               on_generate_state=lambda state, action, cost, successor_state: generated_states.append((state, action, cost, successor_state)),
+               on_generate_new_state=lambda state, action, cost, successor_state: generated_new_states.append((state, action, cost, successor_state)),
+               on_prune_state=lambda state, action, cost, successor_state: pruned_states.append((state, action, cost, successor_state)))
+        assert len(expanded_states) == 7
+        assert len(expanded_goal_states) == 0
+        assert len(generated_states) == 20
+        assert len(generated_new_states) == 5
+        assert len(pruned_states) == 15
+
     def test_str_repr_hash(self):
         domain_path = DATA_DIR / 'blocks_4' / 'domain.pddl'
         problem_path = DATA_DIR / 'blocks_4' / 'test_problem.pddl'
@@ -586,11 +631,12 @@ class TestStateSpaceSampler(unittest.TestCase):
         assert state_label.steps_to_goal == 1
         forward_transitions = list(sampler.get_forward_transitions(state))
         assert len(forward_transitions) > 0
-        for ground_action, successor_state in forward_transitions:
-            assert isinstance(ground_action, GroundAction)
+        for action, successor_state in forward_transitions:
+            assert isinstance(action, GroundAction)
             assert isinstance(successor_state, State)
-            assert ground_action.get_index() is not None
+            assert action.get_index() is not None
             assert successor_state.get_index() is not None
+            assert action.apply(state) == successor_state
 
     def test_backward_transitions(self):
         domain_path = DATA_DIR / 'blocks_4' / 'domain.pddl'
@@ -608,11 +654,12 @@ class TestStateSpaceSampler(unittest.TestCase):
         assert state_label.steps_to_goal == 2
         backward_transitions = list(sampler.get_backward_transitions(state))
         assert len(backward_transitions) > 0
-        for ground_action, predecessor_state in backward_transitions:
-            assert isinstance(ground_action, GroundAction)
+        for action, predecessor_state in backward_transitions:
+            assert isinstance(action, GroundAction)
             assert isinstance(predecessor_state, State)
-            assert ground_action.get_index() is not None
+            assert action.get_index() is not None
             assert predecessor_state.get_index() is not None
+            assert action.apply(predecessor_state) == state
 
     def test_sample_dead_end_state(self):
         domain_path = DATA_DIR / 'spanner' / 'domain.pddl'
